{{ fullname }}
{{ underline }}

.. currentmodule:: {{ module }}

.. class:: {{ objname }}

This is an ndarray wrapper for a native MATLAB object. This class is not meant
to be instantiated directly, but can be used for type checking
:func:`scipy.io.loadmat` outputs.
